<template>
  <LoadingLayout>
    <AppContainer>
      <PageFormLayout>
        <template #title>
          <div class="page-form-layout-title">
            申报详情
            <span class="page-form-layout-title-item status">
              审核状态:<span :style="{ color: BountyCheckStatusEnumColor[form.outCheckStatus] }">{{
                BountyCheckStatusEnumText[form.outCheckStatus]
              }}</span>
            </span>
            <span class="page-form-layout-title-item remark">
              <TextOverTooltip v-if="form.outCheckStatus === BountyCheckStatusEnum.CheckReject">
                {{ `审核未通过原因:${form.outCheckRemark ?? ''}` }}
              </TextOverTooltip>
            </span>
          </div>
        </template>
        <DetailView :form="form">
          <ChunkCellV2 title="申报企业名单">
            <DeclareEnterpriseTableView
              :getList="getList"
              :extra-param-state="extraParamState"
              :pro-table-props="proTableProps"
              :reset="reset"
              :column="addRewardApplyStep3Columns"
              :operationBtns="operationBtns"
            ></DeclareEnterpriseTableView>
            <MateriaDetailDialog
              v-bind="dialogProps"
              :show-upload-btn="false"
              :show-delete-btn="false"
              :show-check-btn="false"
            />
          </ChunkCellV2>
        </DetailView>
        <template #footer>
          <el-button @click="handleBack" type="primary">确认</el-button>
        </template>
      </PageFormLayout>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  AppContainer,
  LoadingLayout,
  PageFormLayout,
  TextOverTooltip,
} from '@bole-core/components';
import ChunkCellV2 from '@/components/Layout/ChunkCellV2.vue';
import DetailView from '@/components/commonView/DetailView.vue';
import MateriaDetailDialog from '@/components/commonView/MateriaDetailDialog.vue';
import DeclareEnterpriseTableView from '@/components/commonView/DeclareEnterpriseTableView.vue';
import { useQuery } from '@tanstack/vue-query';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { useDeclareEnterpriseTable, useRouteView } from '@/hooks';
import {
  BountyCheckStatusEnum,
  BountyCheckStatusEnumText,
  BountyCheckStatusEnumColor,
  useAddRewardApplyStep3Columns,
} from '@/constants';
import {
  CustomerApplyFileTypeListItem,
  EnterpriseApplyFileUtils,
} from '@/components/commonView/utils';
import { useIndustrialParkDropDownList } from '@/hooks/industrialPark';

defineOptions({
  name: 'MaterialReviewDetail',
});

const route = useRoute();
const { closeViewPush } = useRouteView();
const id = route.params?.id as string;
const form = reactive({
  batchNo: '',
  parkName: '',
  parkTypeName: '',
  applyMonth: '',
  applySumAmount: 0,
  financeSumAmount: 0,
  settleSumAmount: 0,
  parkCollectFileList: [] as CustomerApplyFileTypeListItem[],
  calculationFileList: [] as CustomerApplyFileTypeListItem[],

  outCheckStatus: '' as any as BountyCheckStatusEnum,
  outCheckRemark: '',

  suportPlatRecharge: false,
});

const { addRewardApplyStep3Columns } = useAddRewardApplyStep3Columns({
  suportPlatRecharge: toRef(form, 'suportPlatRecharge'),
});

const { extraParamState, getList, reset, proTableProps, operationBtns, dialogProps } =
  useDeclareEnterpriseTable({
    id: ref(id),
    applyMonth: toRef(form, 'applyMonth'),
  });

const tableRef = ref<InstanceType<typeof DeclareEnterpriseTableView>>();

const { data: detail, isLoading } = useQuery({
  queryKey: ['parkBountyApplyServices/getOutCheckParkBountyApplyDetailBaseInfo', id],
  queryFn: async () => {
    return await parkBountyApplyServices.getOutCheckParkBountyApplyDetailBaseInfo(
      { parkBountyApplyId: id },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.OutCheckParkBountyApplyBaseInfo),
  onSuccess(data) {
    form.batchNo = data.batchNo;
    form.parkName = data.parkName;
    form.parkTypeName = data.parkTypeName;
    form.applyMonth = data.applyMonth;
    form.applySumAmount = data.applySumAmount;
    form.financeSumAmount = data.financeSumAmount;
    form.settleSumAmount = data.settleSumAmount;
    form.outCheckStatus = data.outCheckStatus;
    form.outCheckRemark = data.outCheckRemark;
    form.parkCollectFileList = EnterpriseApplyFileUtils.convertApiFileToParkCollectFileList(
      data.listFiles
    );
    form.calculationFileList = EnterpriseApplyFileUtils.convertApiFileToParkCollectFileList(
      data.collectCountListFiles
    );

    form.suportPlatRecharge = data.suportPlatRecharge;

    getList();
  },
});

const { getIndustrialParkTypeNameById } = useIndustrialParkDropDownList();

function handleBack() {
  closeViewPush(route, {
    name: 'MaterialReviewList',
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;

.page-form-layout-title-item {
  margin-left: 16px;
  font-size: 16px;

  &.remark {
    flex: 1;
    min-width: 0;

    @include utils-ellipsis;
  }
}
</style>
